@@ -178,14 +178,14 @@ SVG::Timeline::Compact - A Moose based SVG Timeline drawing class.
 
 =head1 VERSION
 
-version 0.002
+version 0.003
 
 =head1 SYNOPSIS
 
- use SVG::Slotted::Timeline;
+ use SVG::Timeline::Compact;
  use DateTime::Format::Natural;
 
- my $svg=SVG::Slotted::Timeline->new();
+ my $svg=SVG::Timeline::Compact->new();
 
  my $parser = DateTime::Format::Natural->new;
  my $start=$parser->parse_datetime("12pm");
@@ -253,43 +253,62 @@ Tooltips.
 =head1 METHODS
 
 =head2 new
-Creates a new SVG::Slotted::Timeline Object.
+ Creates a new SVG::Timeline::Compact Object.
 
 Takes the following parameters:
 
 =over 4
 
-=item min_width: Default 1, If the event duration is less then min_width then the resultant bar in the graph is made equal to min_width e.g. if start==end then instead of drawing an event with width 0, an event 1 px width is drawn.
+=item min_width:
 
-=item min_height: Default 20, The height of the bar, This assumes that our text is 12 px high.
+ Default 1, If the event duration is less then min_width then the resultant bar in the graph is made equal to min_width e.g. if start==end then instead of drawing an event with width 0, an event 1 px width is drawn.
 
-=item units: Default 800, The width of the drawing area in px. 
+=item min_height:
+
+ Default 20, The height of the bar, This assumes that our text is 12 px high.
+
+=item units:
+
+ Default 800, The width of the drawing area in px. 
 
 =back
 
 =head2 add_event
-Takes a hash corresponding to L<SVG::Timeline::Compact::Event> and adds it to the event list.
+
+ Takes a hash corresponding to L<SVG::Timeline::Compact::Event> and adds it to the event list.
 
 The hash fields are:
 
 =over 4
 
-=item id: Optional, Event ID.
+=item id:
 
-=item start: Required, DateTime Object representing the Start Time.
+ Optional, Event ID.
 
-=item end: Required, DateTime Object representing the End Time.
+=item start:
 
-=item name: Required, Event Name.
+ Required, DateTime Object representing the Start Time.
 
-=item tooltip: Optional, Event Tooltip.
+=item end:
 
-=item color: Optional, The RGB value for filling the rectangle representing the event.
+ Required, DateTime Object representing the End Time.
+
+=item name:
+
+ Required, Event Name.
+
+=item tooltip:
+
+ Optional, Event Tooltip.
+
+=item color:
+
+ Optional, The RGB value for filling the rectangle representing the event.
 
 =back
 
 =head2 to_svg
-Performs an autolayout of all the added events and returns the resultant SVG as a string.
+ Performs an autolayout of all the added events and returns the resultant SVG as a string.
 
 =for html 		<img src="https://raw.githubusercontent.com/jahagirdar/SVG-Timeline-Compact/master/test.svg?sanitize=true" width ="1000">
 
